@@ -1,4 +1,3 @@
-import types
 import logging
 
 from PyQt5.Qt import QObject
@@ -79,7 +78,7 @@ class QObjectAutomator(object):
         elif hasattr(self._target, value_name):
             value = getattr(self._target, value_name)
 
-        if type(value) == types.StringType:
+        if isinstance(value, str):
             return value.decode('utf-8')
 
         return value
